// SSLObject.h
//
// Definition of the SSL object CSSLObject
//
// To compile you must download and have previously
// compiled the OpenSSL library. When using, be sure
// to place the OpenSSL libraries and/or executable files
// in your app's path!
// 
// For OpenSSL see:  www.openssl.org
//
// Kenn Scribner (based upon Simon Fell's OpenSSL Demo)
//
#ifndef __SSLOBJECT_H_
#define __SSLOBJECT_H_

// STL
#include <string>

// Winsock
#include <winsock2.h>

#pragma comment(lib, "ws2_32.lib")

// OpenSLL
#include <openssl/err.h>
#include <openssl/ssl.h>

#pragma comment(lib, "ssleay32.lib")
#pragma comment(lib, "libeay32.lib")

// CSSLObject object definition
class CSSLObject
{
	// Construction/destruction
public:
	CSSLObject();
	~CSSLObject();

	// Methods
	int Init();
	int Open(const std::string& strServer);
	int Read(const std::string& strRequest, std::string& strResults);
	void Close();

	// Static attributes
protected:
	static const int m_iWSVer;
	static const int m_iSSLPort;
	static const int m_iRcvChunkSize;

	// Attributes
protected:
	SOCKET m_Socket;
	SSL_CTX* m_SSLContext;
	SSL* m_SSLConnection;
	SSL_METHOD* m_SSLMethod;
	X509* m_Certificate;

};

#endif // __SSLOBJECT_H_