// SSLObjectTest.cpp
//
// Tests the SSL (OpenSSL) object CSSLObject
//
// To compile you must download and have previously
// compiled the OpenSSL library. When using, be sure
// to place the OpenSSL libraries and/or executable files
// in your app's path!
// 
// For OpenSSL see:  www.openssl.org
//
// Kenn Scribner (based upon Simon Fell's OpenSSL Demo)
//
#include <iostream>
#include "SSLObject.h"

int main( int argc, char* argv[] )
{
	// Print banner
	std::cout << "Kenn's Quick and Dirty C++ OpenSSL Object Test" << std::endl;

	try {
		// Initialize SSL object
		CSSLObject sslo;
		if ( FAILED(sslo.Init()) ) throw "Error initializing SSL object...";

		// Open a connection to the server (www.StreetFusion.com)
		if ( FAILED(sslo.Open(std::string("www.StreetFusion.com"))) ) throw "Error opening SSL connection...";

		// Send the request...in this case we will send an
		// HTTP 1.0 request packet.
		std::string strResults, strRequest("GET /Marketing/about/About.asp?subNav=About&display=Overview HTTP/1.0\r\n\r\n");
		if ( FAILED(sslo.Read(strRequest,strResults)) ) throw "Error reading SSL-protected data...";

		// Close the connection and SSL object
		sslo.Close();

		// Print results
		std::cout << strResults.c_str() << std::endl;
	} // try
	catch(LPTSTR strErr) {
		// Print the error
		std::cout << strErr << std::endl;
	} // catch
	catch(...) {
		// Print error
		std::cout << "Unknown exception in main()" << std::endl;
	} // catch

	return 0;
}